@@ -124,6 +124,17 @@ let init = (app) => {
             axios.post('../new_app', form).then(app.reload);
         }
     };
+    app.process_new_file = () => {
+        var app_name = app.vue.selected_app.name;
+        var form = app.vue.modal.form;
+        if(!form.filename) { alert('An file name must be provided'); return; }
+        /*reload entire page needed to see the new file listed*/
+        axios.post('../new_file/'+app_name+'/'+form.filename).then(function(){
+                app.vue.walk = [];
+                axios.get('../walk/'+app_name).then((res)=>{app.vue.walk=res.data.payload;});
+                app.modal_dismiss();
+            });
+    }; 
     app.handle_upload_file = () => {
         utils.upload_helper('upload-file', (name, data)=>{app.vue.modal.form.file=data;});
     };
@@ -139,7 +150,16 @@ let init = (app) => {
         }; 
     };
     app.create_new_file = ()=> {
-        app.vue.modal = {title:'Create New File', color:'blue', message:'[WORK IN PROGRESS]'};
+        var app_name = app.vue.selected_app.name;
+        app.vue.modal = {
+            title:'Create a new file under ', 
+            color:'green', 
+            message:'Ex: somedir/some_file.py',
+            form_name: 'create-file',
+            form: {'filename': ''},
+            buttons: [{text: 'Create', onclick: function() {app.process_new_file();}}, 
+                      {text:'Close', onclick: app.modal_dismiss}]
+        }; 
     };
     app.upload_new_file = ()=> {
         app.vue.modal ={title:'Upload New File', color:'blue',message:'[WORK IN PROGRESS]'};
