@@ -1,3 +1,4 @@
+
 // ASSUMES Vue and Axios
 
 if (!String.prototype.format) {
@@ -100,9 +101,9 @@ T.format = function(text, args) {
 };
 
 // a Vue app prototype
-utils.app = function(element_id) {
+utils.app = function() {
     self = {};
-    self.element_id = element_id || 'vue';
+    self.element_id = 'vue';
     self.data = { loading: 0, page: null, state: null };
     self.methods = {};
     self.filters = {};
@@ -129,7 +130,7 @@ utils.app = function(element_id) {
                 self.v.state = state;
             }); 
     };
-    // restores state when navigating history
+    // Restores state when navigating history
     self.onpopstate = function(event) {
         for(var key in event.state) self.v[key] = event.state[key];
     };
