@@ -1,7 +1,14 @@
 import urllib
+import calendar
+import time
+import uuid
+import json
+import jwt
+import string
 import requests
 from py4web.core import URL, abort, redirect, request
 
+passedstate=""
 
 class SSO(object):
 
@@ -53,7 +60,7 @@ class SSO(object):
             user["sso_id"] = "%s:%s" % (self.name, user["sso_id"])
             if not 'username' in user:
                 user['username'] = user['sso_id']
-            # store or retrieve the user            
+            # store or retrieve the user
             data = auth.get_or_register_user(user)
         else:
             # WIP Allow login without DB
@@ -90,6 +97,9 @@ class OAuth2(SSO):
             scheme=scheme,
         )
 
+    def state_generator(self, size=18, chars=string.ascii_uppercase + string.digits+string.ascii_lowercase):
+        return ''.join(random.choice(chars) for _ in range(size))
+
     def get_login_url(self, state=None, next=None):
         callback_url = self.parameters.get("callback_url")
         vars = {}
@@ -104,6 +114,7 @@ class OAuth2(SSO):
             client_id=self.parameters.get("client_id"),
         )
         scope = self.parameters.get("scope")
+        state=self.state_generator()
         if scope:
             data["scope"] = scope
             data["include_granted_scopes"] = "true"
@@ -113,8 +124,11 @@ class OAuth2(SSO):
 
     def callback(self, query):
         code = query.get("code")
+        statecheck=query.get("state")
         if not code:
             return False
+        if statecheck != passedstate:
+            return False
         data = dict(
             code=code,
             client_id=self.parameters.get("client_id"),
@@ -128,7 +142,10 @@ class OAuth2(SSO):
         res = requests.post(self.token_url, data=data)
         token = res.json().get("access_token")
         headers = {"Authorization": "Bearer %s" % token}
-        res = requests.get(self.userinfo_url, headers=headers)
+        # Lets not get the  user attributes via the userinfo endpoint
+        # but lets take the userinfo directly extracted from the token
+        #res = requests.get(self.userinfo_url, headers=headers)
+        res=jwt.decode(token, verify=False)
         data = res.json()
         return data
 
